@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2021-2023, by Samuel Williams.
+# Copyright, 2021-2024, by Samuel Williams.
 
 require_relative 'output'
 require_relative 'clock'
@@ -60,7 +60,7 @@ module Sus
 		# The absolute orientation of this set of assertions, i.e. whether the assertions are expected to pass or fail regardless of the parent. Used for correctly formatting the output.
 		attr :orientation
 		
-		# Whether this set of assertions is isolated from the parent. This is used to ensure taht any deferred assertions are competed before the parent is completed. This is used by `receive` assertions which are deferred until the user code of the test has completed.
+		# Whether this set of assertions is isolated from the parent. This is used to ensure that any deferred assertions are competed before the parent is completed. This is used by `receive` assertions which are deferred until the user code of the test has completed.
 		attr :isolated
 		
 		# Distinct is used to identify a set of assertions as a single statement for the purpose of user feedback. It's used by top level ensure statements to ensure that error messages are captured and reported on those statements.
@@ -192,26 +192,13 @@ module Sus
 			
 			if condition
 				@passed << assert
-				
-				if !@orientation || @verbose
-					@output.assert(condition, @orientation, message || "assertion passed", backtrace)
-				end
+				@output.assert(condition, @orientation, message || "assertion passed", backtrace)
 			else
 				@failed << assert
-				
-				if @orientation || @verbose
-					@output.assert(condition, @orientation, message || "assertion failed", backtrace)
-				end
+				@output.assert(condition, @orientation, message || "assertion failed", backtrace)
 			end
 		end
 		
-		def message
-			{
-				text: @output.string,
-				location: @identity&.to_location
-			}
-		end
-		
 		def each_failure(&block)
 			return to_enum(__method__) unless block_given?
 			
