@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2021-2023, by Samuel Williams.
+# Copyright, 2021-2024, by Samuel Williams.
 
 require_relative 'context'
 
@@ -89,5 +89,11 @@ module Sus
 				skip "Ruby #{version} is not supported, but running #{RUBY_VERSION}!"
 			end
 		end
+		
+		def skip_if_ruby_platform(pattern)
+			if match = RUBY_PLATFORM.match(pattern)
+				skip "Ruby platform #{match} is not supported!"
+			end
+		end
 	end
 end
